@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@ class ImportSettingPage : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ImportSettingPage(QWidget *parent = Q_NULLPTR);
+    explicit ImportSettingPage(QWidget *parent = nullptr);
     ~ImportSettingPage();
     void addImportInfo(const QString &log);
     void addImportError(const QString &log);
