@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -34,7 +34,7 @@ class SelectProgramPage : public QWidget
     Q_OBJECT
 
 public:
-    explicit SelectProgramPage(QWidget *parent = Q_NULLPTR);
+    explicit SelectProgramPage(QWidget *parent = nullptr);
     ~SelectProgramPage();
 
     void setFoundProgram(const QStringList &list);
