@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -32,8 +32,10 @@ public:
     explicit ThunderBirdAddressBook(const QDir &dir, ImportWizard *parent);
     ~ThunderBirdAddressBook();
 
+    void importAddressBook();
 private:
     void readAddressBook(const QString &filename);
+    QDir mDir;
 };
 
 #endif // THUNDERBIRDADDRESSBOOK_H
