@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -18,9 +18,10 @@
 */
 
 #include "thunderbirdsettings.h"
-#include <MailTransport/mailtransport/transportmanager.h>
+#include <mailtransport/transportmanager.h>
 #include "MailCommon/MailUtil"
 #include "importwizardutil.h"
+#include "helper_p.h"
 
 #include <KIdentityManagement/kidentitymanagement/identity.h>
 #include <KIdentityManagement/kidentitymanagement/signature.h>
@@ -36,11 +37,21 @@
 #include <QDir>
 
 ThunderbirdSettings::ThunderbirdSettings(const QString &filename, ImportWizard *parent)
-    : AbstractSettings(parent)
+    : AbstractSettings(parent),
+      mFileName(filename)
 {
-    QFile file(filename);
+
+}
+
+ThunderbirdSettings::~ThunderbirdSettings()
+{
+}
+
+void ThunderbirdSettings::importSettings()
+{
+    QFile file(mFileName);
     if (!file.open(QIODevice::ReadOnly)) {
-        qCDebug(IMPORTWIZARD_LOG) << " We can't open file" << filename;
+        qCDebug(IMPORTWIZARD_LOG) << " We can't open file" << mFileName;
         return;
     }
     QTextStream stream(&file);
@@ -82,9 +93,6 @@ ThunderbirdSettings::ThunderbirdSettings(const QString &filename, ImportWizard *
     readExtensionsSettings();
 }
 
-ThunderbirdSettings::~ThunderbirdSettings()
-{
-}
 
 void ThunderbirdSettings::readExtensionsSettings()
 {
@@ -273,7 +281,7 @@ void ThunderbirdSettings::readTagSettings()
 {
     QVector<tagStruct> v;
     v.reserve(mHashTag.size());
-    foreach (const tagStruct &tag, mHashTag) {
+    for (const tagStruct &tag : qAsConst(mHashTag)) {
         v.push_back(tag);
     }
 
@@ -283,7 +291,7 @@ void ThunderbirdSettings::readTagSettings()
 void ThunderbirdSettings::readLdapSettings()
 {
     //qCDebug(IMPORTWIZARD_LOG)<<" mLdapAccountList:"<<mLdapAccountList;
-    Q_FOREACH (const QString &ldapAccountName, mLdapAccountList) {
+    for (const QString &ldapAccountName : qAsConst(mLdapAccountList)) {
         ldapStruct ldap;
         const QString ldapDescription = QStringLiteral("%1.description").arg(ldapAccountName);
         if (mHashConfig.contains(ldapDescription)) {
@@ -482,7 +490,7 @@ void ThunderbirdSettings::addAuth(QMap<QString, QVariant> &settings, const QStri
 
 void ThunderbirdSettings::readAccount()
 {
-    Q_FOREACH (const QString &account, mAccountList) {
+    for (const QString &account : qAsConst(mAccountList)) {
         const QString serverName = mHashConfig.value(QStringLiteral("mail.account.%1").arg(account) + QStringLiteral(".server")).toString();
         const QString accountName = QStringLiteral("mail.server.%1").arg(serverName);
         const QString host = mHashConfig.value(accountName + QStringLiteral(".hostname")).toString();
@@ -491,7 +499,7 @@ void ThunderbirdSettings::readAccount()
 
         const QString type = mHashConfig.value(accountName + QStringLiteral(".type")).toString();
         //TODO use it ?
-        const QString directory = mHashConfig.value(accountName + QStringLiteral(".directory")).toString();
+        //const QString directory = mHashConfig.value(accountName + QStringLiteral(".directory")).toString();
 
         const QString loginAtStartupStr = accountName + QStringLiteral(".login_at_startup");
         bool loginAtStartup = true; //Default for thunderbird;
@@ -652,7 +660,7 @@ void ThunderbirdSettings::readAccount()
         const QString identityConfig = QStringLiteral("mail.account.%1").arg(account) + QStringLiteral(".identities");
         if (mHashConfig.contains(identityConfig)) {
             const QStringList idList = mHashConfig.value(identityConfig).toString().split(QLatin1Char(','));
-            Q_FOREACH (const QString &id, idList) {
+            for (const QString &id : idList) {
                 readIdentity(id);
             }
         }
@@ -665,14 +673,14 @@ void ThunderbirdSettings::readTransport()
     if (mailSmtpServer.isEmpty()) {
         return;
     }
-    QStringList smtpList = mailSmtpServer.split(QLatin1Char(','));
+    const QStringList smtpList = mailSmtpServer.split(QLatin1Char(','));
     QString defaultSmtp = mHashConfig.value(QStringLiteral("mail.smtp.defaultserver")).toString();
     if (smtpList.count() == 1 && defaultSmtp.isEmpty()) {
         //Be sure to define default smtp
         defaultSmtp = smtpList.at(0);
     }
 
-    Q_FOREACH (const QString &smtp, smtpList) {
+    for (const QString &smtp : smtpList) {
         const QString smtpName = QStringLiteral("mail.smtpserver.%1").arg(smtp);
         MailTransport::Transport *mt = createTransport();
         const QString name = mHashConfig.value(smtpName + QStringLiteral(".description")).toString();
@@ -840,7 +848,7 @@ void ThunderbirdSettings::readIdentity(const QString &account)
         KContacts::VCardConverter converter;
         KContacts::Addressee addr = converter.parseVCard(vcard);
 
-        const QString filename = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + newIdentity->identityName() + QStringLiteral(".vcf");
+        const QString filename = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + QLatin1Char('/') + newIdentity->identityName() + QStringLiteral(".vcf");
         QFileInfo fileInfo(filename);
         QDir().mkpath(fileInfo.absolutePath());
         QFile file(filename);
